"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListChannels = void 0;
const ListChannelsCommand_1 = require("../commands/ListChannelsCommand");
const MediaPackageV2Client_1 = require("../MediaPackageV2Client");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListChannelsCommand_1.ListChannelsCommand(input), ...args);
};
async function* paginateListChannels(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof MediaPackageV2Client_1.MediaPackageV2Client) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected MediaPackageV2 | MediaPackageV2Client");
        }
        yield page;
        const prevToken = token;
        token = page.NextToken;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateListChannels = paginateListChannels;
